@@ -10,6 +10,13 @@ import async_timeout
 
 __UPLOADS__ = "/tmp/uploads"
 
+class BaseHandler(tornado.web.RequestHandler):
+    def get_current_user(self):
+        user_json = self.get_secure_cookie("user")
+        if not user_json: 
+            return None
+        return tornado.escape.json_decode(user_json)
+
 class GradeNotebooks():
     async def grade(self, p, notebooks_zip):
         try:
@@ -79,17 +86,16 @@ class GoogleOAuth2LoginHandler(tornado.web.RequestHandler,
         self.set_secure_cookie("user", str(user))
 
         log.write_logs("7.", str(self.current_user), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
-        c = self.get_secure_cookie("user")
-        log.write_logs("8.", str(c), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
         self.redirect("/")
     
-class Userform(tornado.web.RequestHandler,
+class Userform(BaseHandler, tornado.web.RequestHandler,
                                tornado.auth.GoogleOAuth2Mixin):
     async def get(self):
         c = self.get_secure_cookie("user")
-        log.write_logs("1.", str(self.current_user), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
-        log.write_logs("2.", str(c), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
-        if not self.current_user:
+        log.write_logs("1.", str(c), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+        log.write_logs("2.", str(self.get_current_user()), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+        
+        if not self.get_current_user():
             self.redirect("/login")
             return
         
